@@ -18,7 +18,7 @@ use Try::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.48';
+our $VERSION = '0.49';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -296,7 +296,8 @@ sub process_source {
     my $plugin;
 
     if ( $self->verbose ) {
-        $self->msg("[applying the following plugins: @plugins]");
+        my @names = map { $_->name } @plugins;
+        $self->msg("[applying the following plugins: @names]");
     }
 
     my @diffs;
@@ -547,7 +548,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.48
+version 0.49
 
 =head1 SYNOPSIS
 
